
from pathlib import Path

import base64
import hashlib
import datetime
import logging

import pandas as pd

def hashptid(mrn, hosp='NTUH'):

    ptsalt = (mrn+hosp).upper().encode()
    hash_in_bytes = hashlib.md5(ptsalt)

    md5  = hash_in_bytes.hexdigest()
    hash = base64.b32encode(hash_in_bytes.digest())[:8].decode()


    # hash32 = base64.b32encode(hash_in_bytes)[:8].decode()
    # hash10 = str(int(hashlib.md5(ptsalt).hexdigest(), 16))[-8:]

    return md5, hash


  

def main():
    FORMAT = '%(asctime)s %(message)s'
    logging.basicConfig(filename=__file__.replace('.py','.%s.log'%str(datetime.datetime.now()).replace(':','')), 
                        format=FORMAT)

    # df = pd.read_excel('pituitary-op.xlsx')
    # series = df['PatChartNo'].drop_duplicates().iloc[-1000:].iloc[::-1]
    # outdir = r'T:\pituitary-op'

    df = pd.read_excel('pituitary-srs.xlsx', sheet_name='NFA Data (n=178)', header=1)
    series = df[~df['Patient ID'].isna()]['Patient ID'].drop_duplicates()

    for index, row in series.items():
        if isinstance(row, float):
            row = int(row)
        chartno = str(int(row)).zfill(7)
        md5, hash = hashptid(chartno)

        print(chartno, hash)

    return 0


if __name__ == '__main__':
    main()
